
/*** *** *** *** *** *** *** *** *** *** *** *** *** *** *** *** ***************/
/* PROGRAM: UNREVEALING THE FACTORS
/* PURPOSE: PREPARATION FOR REPLICATION
/* PROGRAMMER: HECTOR ZARATE
/*
/* PROCESS: 
/* CREATE DATASETS FOR ANALYSIS:
/* - DIMENSION REDUCTION
/* - FACTORS BEHIND WOMENS EMPOWRMENT IN THE LABOR MARKET IN COLOMBIA
/*
/* DATE: February 25, 2024
/** *** *** *** *** *** *** *** *** *** *** *** *** *** *** *** ****************/
ods results;
options fullstimer;
options nonotes ERRORS=0;
ODS HTML CLOSE;
dm 'log;clear;out;clear';
libname sasf 'C:\Users\hzaratso\OneDrive - Banco de la Repblica\RespaldoDLO\libro_mujeres\';
%INCLUDE 'C:\Users\hzaratso\OneDrive - Banco de la Repblica\RespaldoDLO\libro_mujeres\Tvem_v311.sas'; 


/*Data  input from the original file*/

PROC IMPORT OUT= WORK.mujeres_or
            DATAFILE= "C:\Users\hzaratso\OneDrive - Banco de la Repblica\RespaldoDLO\libro_mujeres\data_sources_definitions.xls" 
            DBMS=EXCEL REPLACE;
     RANGE="original$"; 
     GETNAMES=YES;
     MIXED=NO;
     SCANTEXT=YES;
     USEDATE=YES;
     SCANTIME=YES;
RUN;


/*imputation for missing values in some variables*/

proc expand data=mujeres_or out=expor_im; 
id year;
convert edsup_h   edsup_m  tgp_h   tgp_m edsec_m edsec_h t_matri camara_m senado_m/ method=join;
run;


/*Data  input from the imputed file */

PROC IMPORT OUT= WORK.mujeres
            DATAFILE= "C:\Users\hzaratso\OneDrive - Banco de la Repblica\RespaldoDLO\libro_mujeres\data_sources_definitions.xls"
            DBMS=EXCEL REPLACE;
     RANGE="Expor1$"; 
     GETNAMES=YES;
     MIXED=NO;
     SCANTEXT=YES;
     USEDATE=YES;
     SCANTIME=YES;
RUN;

/* the mujeres file is a subset of expor_im file. It is possible to use any of them to the following process */


data fin_t;set mujeres;
	t=_n_;
	lpibrpc=log(pibr_pc);
	dlpibrpc=dif(lpibrpc);
	w_min_real=log( w_min_real);
	id=1;
run;

data fin_t1;set mujeres_or;
	t=_n_;
	lpibrpc=log(pibr_pc);
	dlpibrpc=dif(lpibrpc);
	w_min_real=log( w_min_real);
	id=1;
run;



/******************************************
			Figure 1
******************************************/
ods listing gpath='C:\Users\hzaratso\OneDrive - Banco de la Repblica\RespaldoDLO' ;
ods graphics on / width=5in height=3.8in  imagename='Figure 1'  OUTPUTFMT=Png;
proc princomp data=fin_t n=3 PLOTS=SCREE out=total;
ods exclude PatternProfilePlot;
var ev_m ev_h mi mi_h mi_m  t_fec tgp_h  t_prim_h t_prim_m t_sec_h t_sec_m t_ter_h t_ter_m  t_matri  mort_mat camara_m 
senado_m  t_homid_h  t_homid_m  w_min_real rural_total dlpibrpc;
run;
 ods graphics off;

/******************************************
			Figure 2
******************************************/
ods listing gpath='C:\Users\hzaratso\OneDrive - Banco de la Repblica\RespaldoDLO' ;
ods graphics on /  width=5in height=3.8in  imagename='Figure 2' OUTPUTFMT=Png;
proc princomp data=fin_t n=3 plots(ncomp=3 )=(PATTERN(vector) PATTERNPROFILE) out=total;
ods select PatternProfilePlot;
var ev_m ev_h mi mi_h mi_m  t_fec tgp_h  t_prim_h t_prim_m t_sec_h t_sec_m t_ter_h t_ter_m  t_matri  mort_mat camara_m 
senado_m  t_homid_h  t_homid_m  w_min_real rural_total dlpibrpc;
ods output PatternProfilePlot;
run;
 ods graphics off;



 /********************************************************************
* Construction of Figues of Appendix 2;
/********************************************************************/

ods listing gpath='C:\Users\hzaratso\OneDrive - Banco de la Repblica\RespaldoDLO' ;
ods graphics on /  reset=index width=5in height=3.8in  imagename='Appendix2_Figure2' OUTPUTFMT=Png;
proc princomp data=fin_t n=3 plots(ncomp=3 )=(PATTERN(vector circles=0.5 1.0) PATTERNPROFILE);
ods exclude ScreePlot;
ods exclude PatternProfilePlot;
var ev_m ev_h mi mi_h mi_m  t_fec tgp_h  t_prim_h t_prim_m t_sec_h t_sec_m t_ter_h t_ter_m  t_matri  mort_mat camara_m 
senado_m  t_homid_h  t_homid_m  w_min_real rural_total dlpibrpc;
*ods output PatternProfilePlot;
run;
 ods graphics off;
/********************************************************************;



 /***********************************************************************************************
						TVEM Specifications
*************************************************************************************************/

proc princomp data=fin_t n=3 out=total1;
var ev_m ev_h mi_h  mi_m  t_fec tgp_h  t_prim_h	 t_prim_m t_sec_h t_sec_m t_ter_h t_ter_m  t_matri  mort_mat camara_m 
senado_m  t_homid_h  t_homid_m  w_min_real rural_total;
run;

data fin_to; set total1;
	t=_n_;
	id=1;
	run;


%TVEM(dist=normal,
	data = fin_to,
	id = id,
	time = t,
	dv = tgp_m,
	tvary_effect = prin1 prin2 prin3,
	method = P-spline,
	knots = 10 10 10 ,
	invar_effect = Id t_prim_h t_prim_m);


data par3p; set tvem_plot_data;
	a=int(t);
run;

%TVEM(dist=normal,
data = fin_t,
	id = id,
	time = t,
	dv = tgp_m,
	tvary_effect =  ev_m ev_h mi tgp_h dlpibrpc t_homid_h t_ter_m w_min_real rural_total camara_m t_homid_m t_matri,
	method = P-spline,
	knots = 10 10 10 10 10 10 10 10 10 10 10 10,
	invar_effect = Id t_prim_m);

data par3m1t; set tvem_plot_data;
	a=int(t);
	run;

%TVEM(dist=normal,
data = fin_t,
id = id,
time = t,
dv = tgp_m,
tvary_effect =  ev_m ev_h mi_m tgp_h dlpibrpc t_homid_h t_ter_m w_min_real rural_total camara_m t_homid_m ,
method = P-spline,
knots = 10 10 10 10 10 10 10 10 10 10 10 ,
invar_effect = Id t_prim_m);

data par3m1; set tvem_plot_data;
a=int(t);
run;


%TVEM(dist=normal,
data = fin_t,
id = id,
time = t,
dv = tgp_m,
tvary_effect =  t_fec ,
method = P-spline,
knots = 10 ,
invar_effect = Id  t_prim_m );

data par3m11;set tvem_plot_data;
a=int(t);
run;

***********************************************************************************;
/*Upper and lower Confidence intervals adjusted for outlier according to percentile 10 and 95*/
************************************************************************************;

  data par3; set par3p;
	a=int(t);
	prin1_L=prin1_L-1;
	prin1_U=prin1_u+1;
	prin2_L=prin2_L-1;
	prin2_U=prin2_u+1;
	prin3_L=prin3_L-1;
	prin3_U=prin3_u+1;
	run;
*******************************;

proc summary nway data=par3m1t;
class a;
var  ev_m_L ev_m ev_m_U ev_h_L ev_h ev_h_U mi_L  mi mi_U tgp_h_L tgp_h tgp_h_U dlpibrpc_L dlpibrpc dlpibrpc_U
t_homid_h_L t_homid_h t_homid_h_U t_ter_m_L t_ter_m t_ter_m_U w_min_real_L w_min_real w_min_real_U  camara_m_L camara_m camara_m_u  rural_total_L   rural_total rural_total_U  t_matri_L t_matri t_matri_U;

output out=par311tt mean= ev_m_L ev_m ev_m_U ev_h_L ev_h  ev_h_U mi_m_L  mi_m mi_m_U tgp_h_L tgp_h tgp_h_U dlpibrpc_L dlpibrpc dlpibrpc_U
t_homid_h_L t_homid_h t_homid_h_U t_ter_m_L t_ter_m t_ter_m_U w_min_real_L w_min_real w_min_real_U  camara_m_L camara_m camara_m_u  rural_total_L rural_total rural_total_U t_matri_L t_matri t_matri_U;
run;



data fin_m1t;set fin_t;
a=_n_;
keep year a;
run;


data fint;
merge par311tt fin_m1t;by a;
run;


proc summary nway data=par3m1;
class a;
var  ev_m_L ev_m ev_m_U ev_h_L ev_h  ev_h_U mi_m_L  mi_m mi_m_U tgp_h_L tgp_h tgp_h_U dlpibrpc_L dlpibrpc dlpibrpc_U
t_homid_h_L t_homid_h t_homid_h_U t_ter_m_L t_ter_m t_ter_m_U w_min_real_L w_min_real w_min_real_U  camara_m_L camara_m camara_m_u  rural_total_L   rural_total rural_total_U;

output out=par311t mean= ev_m_L ev_m ev_m_U ev_h_L ev_h  ev_h_U mi_m_L  mi_m mi_m_U tgp_h_L tgp_h tgp_h_U dlpibrpc_L dlpibrpc dlpibrpc_U
t_homid_h_L t_homid_h t_homid_h_U t_ter_m_L t_ter_m t_ter_m_U w_min_real_L w_min_real w_min_real_U  camara_m_L camara_m camara_m_u  rural_total_L   rural_total rural_total_U;
run;

data fin_m1;set fin_t;
a=_n_;
keep year a;
run;

data fin;
merge par311t fin_m1;by a;
run;



data fin3;
merge par311tt fin_m1;by a;
run;

****************************************************************************;
/*Upper and lower Confidence intervals adjusted for outliers*/

data fin1;set fin;
ev_m_L=ev_m_L-0.2;
ev_m_U=ev_m_U+0.2;
ev_h_L=ev_h_L-0.5;
ev_h_U=ev_h_U+0.5;
mi_m_L=mi_m_L-0.2;
mi_m_U=mi_m_U+0.2;
tgp_h_L=tgp_h_L-0.5;
tgp_h_U=tgp_h_U+0.5;
dlpibrpc_L=dlpibrpc_L/100;
dlpibrpc=dlpibrpc/100;
dlpibrpc_U=dlpibrpc_U/100;
dlpibrpc_L=dlpibrpc_L-0.1;
dlpibrpc_U=dlpibrpc_U+0.1;
t_homid_h_L=t_homid_h_L-0.02;
t_homid_h_U=t_homid_h_U+0.02;
t_ter_m_L=t_ter_m_L-0.5;
t_ter_m_U=t_ter_m_U+0.5;
w_min_real_L=w_min_real_L-1;
w_min_real_U=w_min_real_U+1;
camara_m_L =camara_m_L -0.1;
camara_m_u =camara_m_u +0.1;
rural_total_L=rural_total_L-0.5;
rural_total_U=rural_total_U+0.5;
run;
*************************************************************************;

proc summary nway data=par3m11;
class a;
var  t_fec_L t_fec t_fec_U;
output out=par3m11t mean= t_fec_L t_fec t_fec_U;
run;

data fin_m11;set fin_t;
a=_n_;
keep year a;
run;

data fin_f;
merge par3m11t fin_m11;by a;
run;

proc summary nway data=fin1;
class a;
var  t_ter_m_L t_ter_m t_ter_m_U t_homid_h_L t_homid_h t_homid_h_U;
output out=par31t mean=  t_sec_m_L t_sec_m t_sec_m_U  t_ter_m_L t_ter_m t_ter_m_U t_homid_h_L t_homid_h t_homid_h_U;

run;

data fin_m1;set fin_t;
a=_n_;
keep year a;
run;


data fins;
merge par31t fin_m1;by a;
run;


data finf;
merge par3m11t fin_m1;by a;
run;



proc summary nway data=par3;
class a;
var prin1_L prin1 prin1_U prin2_L prin2 prin2_U  prin3_L prin3 prin3_U ;
output out=par31 mean=prin1_L prin1 prin1_U  prin2_L prin2 prin2_U  prin3_L prin3 prin3_U ;
run;

data fin_m1;set fin_to;
a=_n_;
keep year a;
run;

data fin;
merge par31 fin_m1;by a;
run;

/***********************************************
				Figure 3
************************************************/


ods listing gpath='C:\Users\hzaratso\OneDrive - Banco de la Repblica\RespaldoDLO' ;
ods graphics on / reset=all  width=5in height=3.8in  imagename='Figure 3'  OUTPUTFMT=Png;
PROC SGPLOT DATA = total;
	where t>10;
	styleattrs datacontrastcolors=(red green blue);
	SERIES X = year Y = prin1 /  lineattrs=(thickness=2);
	SERIES X = year Y = prin2/ lineattrs=(thickness=2);
	SERIES X = year Y = prin3/ lineattrs=(thickness=2);
 	TITLE 'Figure 3:  Evolution of the first three components';
 	label prin1='Component 1' prin2='Component 2' prin3='Component 3';
 	YAXIS LABEL = ' Percentage points' VALUES = (-6 TO 6 BY 3); 
  	xaxis  display=(nolabel noline noticks ) fitpolicy=rotatethin
  	valuesrotate=vertical labelattrs=( size=7pt ) valueattrs=( size=7pt );
RUN;
ods graphics off;


/***********************************************
				Figure 4
************************************************/


ods listing gpath='C:\Users\hzaratso\OneDrive - Banco de la Repblica\RespaldoDLO' ;
ods graphics on / reset=all  width=5in height=3.8in  imagename='Figure 4'  OUTPUTFMT=png;

PROC SGPLOT DATA = fin;
	where a>10;
	band x=year lower=prin1_L upper=prin1_U /  LEGENDLABEL = 'Range of variation' fillattrs=(color=GWH);
	SERIES X = year Y = prin1 / LEGENDLABEL = 'Component 1'  
 	LINEATTRS = (color=red thickness=2px);
 	YAXIS LABEL = 'Percentage points   ' GRID VALUES = (0 TO 8 BY 2);
    TITLE 'Figure 4:  First principal component';
 RUN;
ods graphics off;


/***********************************************
				Figure 5
************************************************/


ods listing gpath='C:\Users\hzaratso\OneDrive - Banco de la Repblica\RespaldoDLO' ;
ods graphics on / reset=all  width=5in height=3.8in  imagename='Figure 5'  OUTPUTFMT=png;

PROC SGPLOT DATA = fin;
	where a>10;
	band x=year lower=prin2_L upper=prin2_U / LEGENDLABEL = 'Range of variation' fillattrs=(color=GWH);
	SERIES X = year Y = prin2 / LEGENDLABEL = 'Component 2'
 	LINEATTRS = (color=red thickness=2px);
 	TITLE 'Figure 5: Second principal component';
	YAXIS LABEL = 'Percentage points' GRID VALUES = (-5 TO 15 BY 5);
RUN;
ods graphics off;


/***********************************************
				Figure 6
************************************************/


ods listing gpath='C:\Users\hzaratso\OneDrive - Banco de la Repblica\RespaldoDLO' ;
ods graphics on / reset=all  width=5in height=3.8in  imagename='Figure 6'  OUTPUTFMT=Png;

PROC SGPLOT DATA = fin;
	where a>10;
	band x=year lower=prin3_L upper=prin3_U /  LEGENDLABEL = 'Range of variation' fillattrs=(color=GWH);
	SERIES X = year Y = prin3 / LEGENDLABEL = 'CP-3'
 	LINEATTRS = (color=red thickness=2px);
	 TITLE 'Figue 6: Third principal component';
     YAXIS LABEL = 'Percentage points    ' GRID VALUES = (-2 TO 10 BY 2);
RUN;
ods graphics off;

/***********************************************
				Figure 7
************************************************/


ods listing gpath='C:\Users\hzaratso\OneDrive - Banco de la Repblica\RespaldoDLO' ;
ods graphics on / reset=all  width=5in height=3.8in  imagename='Figure 7'  OUTPUTFMT=png;

PROC SGPLOT DATA = fin_f;
 where a>10;
band x=year lower=t_fec_L upper=t_fec_U / LEGENDLABEL = 'Range of variation' fillattrs=(color=GWH);
SERIES X = year Y = t_fec / LEGENDLABEL = 'Fertility rate'
 LINEATTRS = (color=red thickness=2px);
 TITLE 'Figure 7. Effect of the fertility rate on the female labor force participation rate';
 YAXIS LABEL = 'Percentage points' GRID VALUES = (-10 TO 10 BY 5);
  RUN;

ods graphics off;


/***********************************************
				Figure 8
************************************************/

ods listing gpath='C:\Users\hzaratso\OneDrive - Banco de la Repblica\RespaldoDLO' ;
ods graphics on / reset=all  width=5in height=3.8in  imagename='Figure 8'  OUTPUTFMT=png;

PROC SGPLOT DATA = fin1;
where a>10;
band x=year lower=t_ter_m_L upper=t_ter_m_U /LEGENDLABEL = 'Range of variation' fillattrs=(color=GWH);
SERIES X = year Y=t_ter_m / LEGENDLABEL = 'Female enrollment rate tertiary education'
 LINEATTRS = (color=red thickness=2px);
 TITLE 'Figure 8. Effect of the female enrollment rate in tertiary education on the female labor force
participation rate';
YAXIS LABEL = ' Percentage points   ' GRID VALUES = (-2 TO 3 BY 1);
RUN;
ods graphics off;



/***********************************************
				Figure 9
************************************************/



ods listing gpath='C:\Users\hzaratso\OneDrive - Banco de la Repblica\RespaldoDLO' ;
ods graphics on / reset=all  width=5in height=3.8in  imagename='Figure 9'  OUTPUTFMT=png;

PROC SGPLOT DATA = fint;
where a>10;
band x=year lower=mi_m_L upper=mi_m_U / LEGENDLABEL = 'Range of variation' fillattrs=(color=GWH);
SERIES X = year Y=mi_m / LEGENDLABEL = 'Infant mortality rate'
 LINEATTRS = (color=red thickness=2px);
 TITLE 'Figure 9:  Effect of the infant mortality rate on the female labor force participation rate';
YAXIS LABEL = ' Percentage points   ' GRID VALUES = (-2 TO 2 BY 1);
RUN;
ods graphics off;


/***********************************************
				Figure 10
************************************************/

ods listing gpath='C:\Users\hzaratso\OneDrive - Banco de la Repblica\RespaldoDLO' ;
ods graphics on / reset=all  width=5in height=3.8in  imagename='Figure 10'  OUTPUTFMT=png;

PROC SGPLOT DATA = fint;
where a>10;
band x=year lower=t_matri_L upper=t_matri_U / LEGENDLABEL = 'Range of variation' fillattrs=(color=GWH);
SERIES X = year Y=t_matri / LEGENDLABEL = 'Marriage rate'
 LINEATTRS = (color=red thickness=2px);
 TITLE 'Figure 10: Effect of the marriage rate on the female labor force participation rate';
YAXIS LABEL = 'Percentage points' GRID VALUES = (-2 TO 6 BY 2);
RUN;
ods graphics off;


/***********************************************
				Figure 11
************************************************/

ods listing gpath='C:\Users\hzaratso\OneDrive - Banco de la Repblica\RespaldoDLO' ;
ods graphics on / reset=all  width=5in height=3.8in  imagename='Figure 11'  OUTPUTFMT=png;

PROC SGPLOT DATA = fin1;
 where a>10;
band x=year lower=t_homid_h_L upper=t_homid_h_U / LEGENDLABEL = 'Range of variation' fillattrs=(color=GWH);

SERIES X = year Y = t_homid_h / LEGENDLABEL = 'Male homicide rate'
 LINEATTRS = (color=red thickness=2px);
 TITLE 'Figure 11: Effect of the male homicide rate on the female labor force participation rate';
 YAXIS LABEL = 'Percentage points' GRID VALUES = (-0.1 TO 0.2 BY 0.1);
 RUN;
ods graphics off;



/***********************************************
				Figure 12
************************************************/

ods listing gpath='C:\Users\hzaratso\OneDrive - Banco de la Repblica\RespaldoDLO' ;
ods graphics on / reset=all  width=5in height=3.8in  imagename='Figure 12'  OUTPUTFMT=png;
PROC SGPLOT DATA = fin1;
where a>10;
band x=year lower=camara_m_L  upper=camara_m_U  / LEGENDLABEL = 'Range of variation' fillattrs=(color=GWH);

SERIES X = year Y =camara_m / LEGENDLABEL = 'Female political participation'
 LINEATTRS = (color=red thickness=2px);
 TITLE 'Figure 12:  Effect of female political participation (chamber of representatives) on the female labor force participation rate  ';
 YAXIS LABEL = 'Percentage points    ' GRID VALUES = (-0.4 TO 0.6 BY 0.2);
 RUN;

ods graphics off;


/***********************************************
				Figure 13
************************************************/


ods listing gpath='C:\Users\hzaratso\OneDrive - Banco de la Repblica\RespaldoDLO' ;
ods graphics on / reset=all  width=5in height=3.8in  imagename='Figure 13'  OUTPUTFMT=png;

PROC SGPLOT DATA = fin1;
where a>10;
band x=year lower=dlpibrpc_L upper=dlpibrpc_U /LEGENDLABEL = 'Range of variation'  fillattrs=(color=GWH);
SERIES X = year Y = dlpibrpc / LEGENDLABEL = 'PIB'
 LINEATTRS = (color=red thickness=2px);
 TITLE 'Figure 13: Effect of real GDP per capita growth on the female labor force participation rate   ';
 YAXIS LABEL = 'Percentage points';
 YAXIS LABEL = 'Percentage points    ' GRID VALUES = (-0.2 TO 0.8 BY 0.2);
 RUN;
ods graphics off;



/***********************************************
				Figure 14
************************************************/


ods listing gpath='C:\Users\hzaratso\OneDrive - Banco de la Repblica\RespaldoDLO' ;
 ods graphics on / reset=all  width=5in height=3.8in  imagename='Figure 14'  OUTPUTFMT=png;

PROC SGPLOT DATA = fin1;
where a>10;
band x=year lower=tgp_h_L upper=tgp_h_U / LEGENDLABEL = 'Range of variation' fillattrs=(color=GWH);

SERIES X = year Y = tgp_h / LEGENDLABEL = 'Male labor participation rate'
 LINEATTRS = (color=red thickness=2px);
 TITLE 'Figure 14: Effect of the m_lfp_r on the f_lfp_r';
 YAXIS LABEL = 'Percentage points' GRID VALUES = (-1 TO 3 BY 1);
  RUN;
ods graphics off;


/***********************************************
				Figure 15
************************************************/

ods listing gpath='C:\Users\hzaratso\OneDrive - Banco de la Repblica\RespaldoDLO' ;
 ods graphics on / reset=all  width=5in height=3.8in  imagename='Figure 15'  OUTPUTFMT=png;

PROC SGPLOT DATA = expor_im;
where  year>1959;
 SERIES X = year Y = tgp_h / LEGENDLABEL = 'Male labor participation rate';
 SERIES X = year Y = tgp_m / LEGENDLABEL = 'Female labor participation rate';
 TITLE1 'Figure 15: Male and female Labor participation rates 1960-2018';
 TITLE2 '(average seven cities)';
 XAXIS LABEL = '   ' VALUES = (1960 TO 2018 BY 1);
 YAXIS LABEL = 'Percentage (%)' VALUES = (0 TO 90 BY 10);
  RUN;
ods graphics off;


/***********************************************
				Figure 16
************************************************/


ods listing gpath='C:\Users\hzaratso\OneDrive - Banco de la Repblica\RespaldoDLO' ;
ods graphics on / reset=all  width=5in height=3.8in  imagename='Figure 16'  OUTPUTFMT=png;

PROC SGPLOT DATA = fin1;
where a>10;
band x=year lower=w_min_real_L upper=w_min_real_U /  LEGENDLABEL = 'Range of variation' fillattrs=(color=GWH);
SERIES X = year Y =w_min_real / LEGENDLABEL = 'Minimun wage'
 LINEATTRS = (color=red thickness=2px);
 TITLE 'Figure 16: Effect of the real minimum wage on the female labor force participation rate  ';
 YAXIS LABEL = 'Percentage points    ' GRID VALUES = (-20 TO 20 BY 10);
 RUN;
ods graphics off;


/********************************************************
			Appendix . 	Table A1.2 adjusted to 1960-2018
*********************************************************/
data tabla2;set mujeres;

options nodate nonumber printerpath=png papersize=('10in','10in');
*ods listing close;
ods printer file='C:\Users\hzaratso\OneDrive - Banco de la Repblica\RespaldoDLO\Table A12.png';

proc tabulate data=tabla2 format=8.2 ; 
where year>1959;
var tgp_h tgp_m  ev_m ev_h mi mi_h  mi_m mort_mat t_fec t_matri t_prim_h t_prim_m t_sec_h t_sec_m t_ter_h t_ter_m   t_homid_h  t_homid_m camara_m 
senado_m  w_min_real pibr_pc;

table  tgp_h tgp_m  ev_m ev_h mi mi_h  mi_m mort_mat t_fec t_matri t_prim_h t_prim_m t_sec_h t_sec_m t_ter_h t_ter_m   t_homid_h  t_homid_m camara_m 
senado_m   w_min_real*f=comma16.0 pibr_pc*f=comma16.0, mean std min max/Box='  ' rts=50 ;
Title ' Descriptive statistics 1960-2018';
label 
tgp_h='Labor force participation rate (Males)'
tgp_h='Labor force participation rate (Females)'
ev_h='Life expectancy at birth (Males)'
ev_m='Life expectancy at birth (Females)'
mi='Infant mortality rate'
mi_h='Infant mortality rate (Males)' 
mi_m='Infant mortality rate (Females)'
t_fec='Fertility rate'
tgp_h='Labor force participation rate (Males)'
tgp_m='Labor force participation rate (Females)'
t_prim_m='Gross enrollment rate primary education (Males)'
t_prim_h='Gross enrollment rate primary education (Females)'
t_sec_m='Gross enrollment rate secondary education (Males)'
t_sec_h='Gross enrollment rate secondary education (Females)'
t_ter_m='Gross enrollment rate higher education (Males)'
t_ter_h='Gross enrollment rate higher education (Females)'
 t_matri='Marriage rate '
 mort_mat='Maternal mortality rate'
camara_m='Chamber of representatives (Females)'
senado_m='Senate (Females)'
t_homid_m='Homicide rate (Males)'
t_homid_h='Homicide rate (Females)'
w_min_real='Real minimum wage'
pibr_pc='Real GDP pc';
run;
ods printer close;
ods listing;
ods _all_ close;
/***********************************************
		Code for Appendix 3. 	Table A3.1
*************************************************/

ods output Eigenvectors=eigen;
ods graphics on;

proc princomp data=fin_t n=3 plots(ncomp=3 )=(PATTERN(vector) PATTERNPROFILE) out=total;
ods exclude PatternProfilePlot;
ods exclude PatternPlot1;
ods exclude PatternPlot2;
ods exclude PatternPlot;
ods exclude ScreePlot;

var ev_m ev_h mi mi_h mi_m  t_fec tgp_h  t_prim_h t_prim_m t_sec_h t_sec_m t_ter_h t_ter_m  t_matri  mort_mat camara_m 
senado_m  t_homid_h  t_homid_m  w_min_real rural_total dlpibrpc;
 
Label
ev_m='Life expectancy at birth (Females)'
ev_h='Life expectancy at birth (Males)'
mi='Infant mortality rate'
mi_h='Infant mortality rate (Males)' 
mi_m='Infant mortality rate (Females)'
t_fec='Fertility rate'
tgp_h='Labor force participation rate (Males)'
t_prim_m='Gross enrollment rate primary education (Males)'
t_prim_h='Gross enrollment rate primary education (Females)'
t_sec_m='Gross enrollment rate secondary education (Males)'
t_sec_h='Gross enrollment rate secondary education (Females)'
t_ter_m='Gross enrollment rate higher education (Males)'
t_ter_h='Gross enrollment rate higher education (Females)'
 t_matri='Marriage rate '
 mort_mat='Maternal mortality rate'
t_homid_m='Homicide rate (Males)'
t_homid_h='Homicide rate (Females)'
camara_m='Chamber of representatives (Females)'
senado_m='Senate (Females)'
w_min_real='Real minimum wage'
dlpibrpc='Real GDP pc growth';
ods output PatternProfilePlot;
run;
ods graphics off;

data fin_ed;set eigen;
CP1=prin1;
CP2=prin2;
CP3=prin3;
if variable='ev_m' then variable='f_life_exp';
if variable='ev_h' then variable='m_life_exp      ';
if variable='mi' then variable='inf_mort_r    ';
if variable='mi_h' then variable='m_inf_mort_r ';
if variable='mi_m' then variable=' f_inf_mort_r ';
if variable='t_fec' then variable=' fert_r ';
if variable='tgp_h' then variable=' m_lfp_r';
if variable='t_prim_m' then variable='m_enrol_p ';
if variable='t_prim_h' then variable='f_enrol_p';
if variable='t_sec_m' then variable=' m_enrol_s ';
if variable='t_sec_h' then variable=' f_enrol_s';
if variable='t_ter_m' then variable=' f_inf_mort_r ';
if variable='t_ter_h' then variable=' m_enrol_h';
if variable='t_matri' then variable=' f_enrol_h';
if variable='camara_m' then variable='f_chamber';
if variable='senado_m' then variable='f_senate ';
if variable='t_homid_m' then variable='m_hom_r';
if variable='t_homid_h' then variable='f_hom_r';
if variable='w_min_real' then variable='rminw';
if variable='dlpibrpc' then variable='rgdppc_g';
drop prin1 prin2 prin3 ;
run;


/***********************************************
			Appendix 3. 	Table A3.1
*************************************************/
options ps=66 ls=130;
proc report data=fin_ed;
 Title1 'Table A3.1 Correlation between each variable and its components';
run;
 
*********************image output Table A3.1********************************;
ods _all_ close;
ods printer file='C:\Users\hzaratso\OneDrive - Banco de la Repblica\RespaldoDLO\Table A31.png';
 proc report data=fin_ed;
 Title1 'Table A3.1 Correlation between each variable and its components';run;
ods printer close;
ods listing;
***********************************END*******************************************;
